---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run command `niveshpy ...`
2. Enter input '...'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Logs**
If applicable, paste an extract of the log file below:

<details>

```
REPLACE WITH YOUR LOG CONTENTS
```
</details>

**Additional context**
Add any other context about the problem here.
